@@ -23,7 +23,7 @@ __docformat__ = "restructuredtext en"
 
 import sys
 import types
-from time import clock, time
+from time import process_time, time
 from inspect import isgeneratorfunction
 
 import six
@@ -232,10 +232,10 @@ class iclassmethod(object):
 def timed(f):
     def wrap(*args, **kwargs):
         t = time()
-        c = clock()
+        c = process_time()
         res = f(*args, **kwargs)
         print('%s clock: %.9f / time: %.9f' % (f.__name__,
-                                               clock() - c, time() - t))
+                                               process_time() - c, time() - t))
         return res
     return wrap
 
